import AuthenticatedLayout from '@/Layouts/AuthenticatedLayout';
import { Head } from '@inertiajs/react';
import { AdUnitsIndexProps } from '@/types';
import { BarChart, Eye, DollarSign, MousePointer, Server } from "lucide-react";

export default function Index({ adunits }: AdUnitsIndexProps) {
    // Icon mapping for the stats
    const icons = {
        ecpm: <BarChart className="text-blue-500 w-5 h-5" />,
        impressions: <Eye className="text-green-500 w-5 h-5" />,
        revenue: <DollarSign className="text-yellow-500 w-5 h-5" />,
        clicks: <MousePointer className="text-red-500 w-5 h-5" />,
        requests: <Server className="text-purple-500 w-5 h-5" />,
    };

    return (
        <AuthenticatedLayout>
            <Head title="Ad Units" />
            <div className="bg-gradient-to-r from-blue-50 via-white to-blue-100 min-h-screen p-6">
                <div className="bg-white shadow-md rounded-lg px-6 py-4 mb-6">
                    <h4 className="text-2xl font-bold text-gray-800">Ad Units Overview</h4>
                    <p className="text-gray-500 text-sm mt-1">Manage your ad units and view performance metrics</p>
                </div>

                <div className="grid grid-cols-1 sm:grid-cols-2 md:grid-cols-3 lg:grid-cols-4 gap-6">
                    {adunits.map((adunit:any, index:any) => (
                        <div
                            key={index}
                            className="bg-white shadow-lg rounded-xl border border-gray-200 p-6 hover:shadow-xl transition-transform transform hover:scale-105"
                        >
                            <h2 className="text-lg font-semibold text-gray-800 mb-2">{adunit.ad_unit_id}</h2>
                            <p className="text-sm text-gray-500 mb-4">{adunit.site_name}</p>

                            <div className="space-y-4">
                                {[
                                    {
                                        label: "ECPM",
                                        value: adunit.ad_exchange_line_item_level_impressions > 0 ? "$ " + ((adunit.ad_exchange_line_item_level_revenue / adunit.ad_exchange_line_item_level_impressions)*100).toFixed(2) : 0,

                                        icon: icons.ecpm,
                                    },
                                    {
                                        label: "Impressions",
                                        value: adunit.ad_exchange_line_item_level_impressions,
                                        icon: icons.impressions,
                                    },
                                    {
                                        label: "Revenue",
                                        value: "$ " + adunit.ad_exchange_line_item_level_revenue,
                                        icon: icons.revenue,
                                    },
                                    {
                                        label: "Clicks",
                                        value: adunit.ad_exchanage_line_item_level_clicks,
                                        icon: icons.clicks,
                                    },
                                    {
                                        label: "Requests",
                                        value: adunit.ad_exchange_total_requests,
                                        icon: icons.requests,
                                    },
                                ].map((stat, idx) => (
                                    <div
                                        key={idx}
                                        className="flex items-center justify-between border-b last:border-none pb-2"
                                    >
                                        <div className="flex items-center gap-2">
                                            {stat.icon}
                                            <span className="text-sm font-medium text-gray-700">{stat.label}</span>
                                        </div>
                                        <span className="text-sm font-semibold text-gray-800">{stat.value}</span>
                                    </div>
                                ))}
                            </div>
                        </div>
                    ))}
                </div>
            </div>
        </AuthenticatedLayout>
    );
}
